Exception: Insika::Error
- Inherits:
-
StandardError
- Object
- StandardError
- Insika::Error
- Defined in:
- lib/insika/errors.rb
Overview
Single error taxonomy. General rule: an error becomes an event, a task has an explicit terminal state, a checkpoint is never corrupted.
Direct Known Subclasses
BudgetExceeded, CancelledError, CapabilityError, CircuitOpenError, ConfigError, ConfigStore::UnknownScope, ContextError, DeliveryError, HttpClient::ResponseTooLarge, MediaError, NotFoundError, PolicyDenied, ProviderError, RoutingError, Soak::Runner::PreflightError, StoreError, TimeoutError, ValidationError