Exception: Insika::Error

Inherits:
StandardError
  • Object
show all
Defined in:
lib/insika/errors.rb

Overview

Single error taxonomy. General rule: an error becomes an event, a task has an explicit terminal state, a checkpoint is never corrupted.