Class: Insika::Wiring::Graph::Result

Inherits:
Struct
  • Object
show all
Defined in:
lib/insika/wiring/graph.rb

Overview

Full graph (phase 2 output). code_tool_registry is the plain code registry (REGISTRY); tool_registry is the effective one the Executor uses (the deployment's overlay, or the same code registry at the base).

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#backendObject

Returns the value of attribute backend

Returns:

  • (Object)

    the current value of backend



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def backend
  @backend
end

#budget_ledgerObject

Returns the value of attribute budget_ledger

Returns:

  • (Object)

    the current value of budget_ledger



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def budget_ledger
  @budget_ledger
end

#busObject

Returns the value of attribute bus

Returns:

  • (Object)

    the current value of bus



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def bus
  @bus
end

#capability_registryObject

Returns the value of attribute capability_registry

Returns:

  • (Object)

    the current value of capability_registry



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def capability_registry
  @capability_registry
end

#channel_deliveryObject

Returns the value of attribute channel_delivery

Returns:

  • (Object)

    the current value of channel_delivery



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def channel_delivery
  @channel_delivery
end

#channel_registryObject

Returns the value of attribute channel_registry

Returns:

  • (Object)

    the current value of channel_registry



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def channel_registry
  @channel_registry
end

#checkpoint_storeObject

Returns the value of attribute checkpoint_store

Returns:

  • (Object)

    the current value of checkpoint_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def checkpoint_store
  @checkpoint_store
end

#circuit_stateObject

Returns the value of attribute circuit_state

Returns:

  • (Object)

    the current value of circuit_state



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def circuit_state
  @circuit_state
end

#code_tool_registryObject

Returns the value of attribute code_tool_registry

Returns:

  • (Object)

    the current value of code_tool_registry



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def code_tool_registry
  @code_tool_registry
end

#contact_storeObject

Returns the value of attribute contact_store

Returns:

  • (Object)

    the current value of contact_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def contact_store
  @contact_store
end

#context_builderObject

Returns the value of attribute context_builder

Returns:

  • (Object)

    the current value of context_builder



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def context_builder
  @context_builder
end

#context_providersObject

Returns the value of attribute context_providers

Returns:

  • (Object)

    the current value of context_providers



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def context_providers
  @context_providers
end

#delegation_storeObject

Returns the value of attribute delegation_store

Returns:

  • (Object)

    the current value of delegation_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def delegation_store
  @delegation_store
end

#event_streamObject

Returns the value of attribute event_stream

Returns:

  • (Object)

    the current value of event_stream



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def event_stream
  @event_stream
end

#executorObject

Returns the value of attribute executor

Returns:

  • (Object)

    the current value of executor



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def executor
  @executor
end

#followup_storeObject

Returns the value of attribute followup_store

Returns:

  • (Object)

    the current value of followup_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def followup_store
  @followup_store
end

#funnel_storeObject

Returns the value of attribute funnel_store

Returns:

  • (Object)

    the current value of funnel_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def funnel_store
  @funnel_store
end

#guardrailsObject

Returns the value of attribute guardrails

Returns:

  • (Object)

    the current value of guardrails



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def guardrails
  @guardrails
end

#harvest_storeObject

Returns the value of attribute harvest_store

Returns:

  • (Object)

    the current value of harvest_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def harvest_store
  @harvest_store
end

#hooksObject

Returns the value of attribute hooks

Returns:

  • (Object)

    the current value of hooks



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def hooks
  @hooks
end

#inbound_logObject

Returns the value of attribute inbound_log

Returns:

  • (Object)

    the current value of inbound_log



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def inbound_log
  @inbound_log
end

#memory_audit_storeObject

Returns the value of attribute memory_audit_store

Returns:

  • (Object)

    the current value of memory_audit_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def memory_audit_store
  @memory_audit_store
end

#memory_storeObject

Returns the value of attribute memory_store

Returns:

  • (Object)

    the current value of memory_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def memory_store
  @memory_store
end

#middlewareObject

Returns the value of attribute middleware

Returns:

  • (Object)

    the current value of middleware



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def middleware
  @middleware
end

#outbox_storeObject

Returns the value of attribute outbox_store

Returns:

  • (Object)

    the current value of outbox_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def outbox_store
  @outbox_store
end

#outcome_storeObject

Returns the value of attribute outcome_store

Returns:

  • (Object)

    the current value of outcome_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def outcome_store
  @outcome_store
end

#pending_action_storeObject

Returns the value of attribute pending_action_store

Returns:

  • (Object)

    the current value of pending_action_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def pending_action_store
  @pending_action_store
end

#policy_engineObject

Returns the value of attribute policy_engine

Returns:

  • (Object)

    the current value of policy_engine



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def policy_engine
  @policy_engine
end

#policy_registryObject

Returns the value of attribute policy_registry

Returns:

  • (Object)

    the current value of policy_registry



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def policy_registry
  @policy_registry
end

#profilesObject

Returns the value of attribute profiles

Returns:

  • (Object)

    the current value of profiles



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def profiles
  @profiles
end

#prompt_catalogObject

Returns the value of attribute prompt_catalog

Returns:

  • (Object)

    the current value of prompt_catalog



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def prompt_catalog
  @prompt_catalog
end

#proposal_storeObject

Returns the value of attribute proposal_store

Returns:

  • (Object)

    the current value of proposal_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def proposal_store
  @proposal_store
end

#refinement_storeObject

Returns the value of attribute refinement_store

Returns:

  • (Object)

    the current value of refinement_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def refinement_store
  @refinement_store
end

#session_storeObject

Returns the value of attribute session_store

Returns:

  • (Object)

    the current value of session_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def session_store
  @session_store
end

#shadow_pair_storeObject

Returns the value of attribute shadow_pair_store

Returns:

  • (Object)

    the current value of shadow_pair_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def shadow_pair_store
  @shadow_pair_store
end

#skill_catalogObject

Returns the value of attribute skill_catalog

Returns:

  • (Object)

    the current value of skill_catalog



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def skill_catalog
  @skill_catalog
end

#task_storeObject

Returns the value of attribute task_store

Returns:

  • (Object)

    the current value of task_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def task_store
  @task_store
end

#token_storeObject

Returns the value of attribute token_store

Returns:

  • (Object)

    the current value of token_store



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def token_store
  @token_store
end

#tool_catalogObject

Returns the value of attribute tool_catalog

Returns:

  • (Object)

    the current value of tool_catalog



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def tool_catalog
  @tool_catalog
end

#tool_registryObject

Returns the value of attribute tool_registry

Returns:

  • (Object)

    the current value of tool_registry



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def tool_registry
  @tool_registry
end

#workflow_registryObject

Returns the value of attribute workflow_registry

Returns:

  • (Object)

    the current value of workflow_registry



516
517
518
# File 'lib/insika/wiring/graph.rb', line 516

def workflow_registry
  @workflow_registry
end

Instance Method Details

#durable?Boolean

Returns:

  • (Boolean)


532
# File 'lib/insika/wiring/graph.rb', line 532

def durable? = backend.is_a?(Insika::Stores::SQLite)